@@ -19,7 +19,7 @@ class MagicException(Exception):
         self.message: str = message
         self.json_response: dict = json_response or {}
 
-    def make_model(self) -> MagicExceptionModel:
+    def model(self) -> MagicExceptionModel:
         return MagicExceptionModel(**self.__dict__)
 
 
@@ -42,7 +42,7 @@ class TwilioException(MagicException):
 @g.app.exception_handler(MagicException)
 def backend_exception_handler(request: Request, exc: MagicException):
     print("EXC", exc.__dict__)
-    magic_exception_model = exc.make_model()
+    magic_exception_model = exc.model()
     return JSONResponse(
         status_code=magic_exception_model.status_code,
         content=magic_exception_model.dict(),
